package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERNull;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.pkcs.PKCSObjectIdentifiers;
import cn.com.infosec.asn1.pkcs.PrivateKeyInfo;
import cn.com.infosec.asn1.pkcs.RSAPrivateKeyStructure;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.crypto.params.RSAKeyParameters;
import cn.com.infosec.jce.interfaces.PKCS12BagAttributeCarrier;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.math.BigInteger;
import java.security.interfaces.RSAPrivateKey;
import java.security.spec.RSAPrivateKeySpec;
import java.util.Enumeration;

public class JCERSAPrivateKey implements RSAPrivateKey, PKCS12BagAttributeCarrier {
   static final long serialVersionUID = 5110188922551353628L;
   private static BigInteger ZERO = BigInteger.valueOf(0L);
   protected BigInteger modulus;
   protected BigInteger privateExponent;
   private PKCS12BagAttributeCarrierImpl attrCarrier;

   protected JCERSAPrivateKey() {
      JCERSAPrivateKey var10000 = this;
      super();
      PKCS12BagAttributeCarrierImpl var1;
      var1 = new PKCS12BagAttributeCarrierImpl.<init>();
      var10000.attrCarrier = var1;
   }

   JCERSAPrivateKey(RSAKeyParameters key) {
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.modulus = key.getModulus();
      this.privateExponent = key.getExponent();
   }

   JCERSAPrivateKey(RSAPrivateKeySpec spec) {
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.modulus = spec.getModulus();
      this.privateExponent = spec.getPrivateExponent();
   }

   JCERSAPrivateKey(RSAPrivateKey key) {
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.modulus = key.getModulus();
      this.privateExponent = key.getPrivateExponent();
   }

   private void readObject(ObjectInputStream in) {
      this.modulus = (BigInteger)in.readObject();
      PKCS12BagAttributeCarrierImpl var2;
      PKCS12BagAttributeCarrierImpl var10002 = var2 = new PKCS12BagAttributeCarrierImpl;
      var2.<init>();
      this.attrCarrier = var2;
      var10002.readObject(in);
      this.privateExponent = (BigInteger)in.readObject();
   }

   private void writeObject(ObjectOutputStream out) {
      out.writeObject(this.modulus);
      this.attrCarrier.writeObject(out);
      out.writeObject(this.privateExponent);
   }

   public BigInteger getModulus() {
      return this.modulus;
   }

   public BigInteger getPrivateExponent() {
      return this.privateExponent;
   }

   public String getAlgorithm() {
      return "RSA";
   }

   public String getFormat() {
      return "PKCS#8";
   }

   public byte[] getEncoded() {
      AlgorithmIdentifier var10002 = new AlgorithmIdentifier(PKCSObjectIdentifiers.rsaEncryption, new DERNull());
      JCERSAPrivateKey var10005 = this;
      BigInteger var3 = this.getModulus();
      BigInteger var1 = ZERO;
      BigInteger var2 = var10005.getPrivateExponent();
      BigInteger var10008 = ZERO;
      return (new PrivateKeyInfo(var10002, (new RSAPrivateKeyStructure(var3, var1, var2, var10008, var10008, var10008, var10008, var10008)).getDERObject())).getDEREncoded();
   }

   public boolean equals(Object o) {
      if (!(o instanceof RSAPrivateKey)) {
         return false;
      } else if (o == this) {
         return true;
      } else {
         RSAPrivateKey o1 = (RSAPrivateKey)o;
         return this.getModulus().equals(o1.getModulus()) && this.getPrivateExponent().equals(o1.getPrivateExponent());
      }
   }

   public int hashCode() {
      return this.getModulus().hashCode() ^ this.getPrivateExponent().hashCode();
   }

   public void setBagAttribute(DERObjectIdentifier oid, DEREncodable attribute) {
      this.attrCarrier.setBagAttribute(oid, attribute);
   }

   public DEREncodable getBagAttribute(DERObjectIdentifier oid) {
      return this.attrCarrier.getBagAttribute(oid);
   }

   public Enumeration getBagAttributeKeys() {
      return this.attrCarrier.getBagAttributeKeys();
   }
}
